#==============================================================================
#				INTERFAZ GRAFICA PARA UN JUEGO CON TABLERO
#							CC1001 - 2011-01
#				Carlos Gonzalez Cortes - carlgonz@ug.uchile.cl
#==============================================================================

from Tkinter import*
from Gato import* #IMPORTAR LA CLASE GATO

class GUI(Frame):
	def __init__(self,ventana,master=None):
		Frame.__init__(self, master)
		self.n=3
		self.ancho=300
		self.alto=300
		#Se crea un objeto de la clase gato.
		self.gato=Gato()
		self.matriz_previa=self.InitMatrix(self.n)

		# Se organiza la interfaz
		self.ventana=ventana
		self.canvas=Canvas(self.ventana, width=self.ancho,height=self.alto, bg="white")
		self.canvas.pack()
		self.canvas.bind("<Button-1>",self.GetMouse)
		
		#Dibujo los elementos base de la interfaz
		self.SetCanvas()
		
	def SetCanvas(self):
	##
	#	Dibuja los elementos base de la interfaz
	#	creando un tablero de juego de nxn casilleros
	#	y posicionando las primeras piezas en el tablero
	##
		i=2
		j=2
		di=self.alto/self.n
		dj=self.ancho/self.n
		while i<self.alto:
			self.canvas.create_line(i,0,i,self.ancho,width=5,fill="grey")
			i+=di
		while j<self.ancho:
			self.canvas.create_line(0,j,self.alto,j,width=5,fill="grey")
			j+=dj
	
	def GetMouse(self,event):
	##
	#	Este metodo esta escuchando los eventos del mouse
	#	Determina en que casillero quiere jugar el usuario
	#	e invoca al objeto Gato para que intente realizar
	#	una jugada en determinada posicion. En caso de ser
	#	una jugada valida, redibujo el tablero para ver los cambios
	##
		i=event.x/(self.alto/self.n)
		j=event.y/(self.alto/self.n)
		#Antes de realizar una nueva jugada voy a guardar el estado del juego
		self.SaveMatrix() 
		#print [i,j]
		if self.gato.jugar(i,j):
			#Jugada valida, hay que mostrar como queda el juego ahora
			self.DrawPieces()

		
	def DrawPieces(self):
	##
	#	Este metodo se encarga de dibujar las piezas en el tablero
	#	segun la informacion que extrae desde la matriz que todo
	#	objeto de la clase Gato posee.
	#	Recorre la matriz dibujando un circulo del color que corresponda
	#	siempre y cuando ese casillero haya cambiado su estado.
	##
		for i in range(self.gato.n):
			for j in range(self.gato.n):
				if self.gato.matriz[i][j]!=self.matriz_previa[i][j]:
				##
				#	Esto es una optimizacion del codigo: dibujar cosas en la pantalla
				#	es una operacion lenta, por lo tanto, matriz_previa guarda el estado
				#	anterior del juego para dibujar solo las fichas que han cambiado
				#	de color en la jugada actual
				##
					pi=i*(self.alto/self.n)+8 #Convierto de casilleros
					pj=j*(self.alto/self.n)+8 #a los pixeles del canvas
					if self.gato.matriz[i][j]==1:
						color="blue"
					elif self.gato.matriz[i][j]==2:
						color="red"
					else:
					#un 0 indica no dibujar pieza 
						continue
					self.canvas.create_oval(pi+10,pj+10,pi+70,pj+70,fill=color,outline=color)
				else:
					continue
					
	def SaveMatrix(self):
	##
	#	Permite recordar el estado anterior
	#	del juego para no redibujar todo el tablero
	##
		for i in range(self.n):
			for j in range(self.n):
				self.matriz_previa[i][j]=self.gato.matriz[i][j]
			
	def InitMatrix(self,n):
	##
	#	Crea una nueva matriz de nxn
	#	rellena de ceros
	##
		matrix=[]
		for i in range(n):
			matrix.append([0]*n)
		return matrix
		
		
#################  PROGRAMA PRINCIPAL ################
v=Tk()
gui=GUI(v)
gui.master.title("Gato")
mainloop()
#################  PROGRAMA PRINCIPAL ################
